@@ -3,11 +3,20 @@ from __future__ import annotations
 import os
 from dataclasses import dataclass
 from pathlib import Path
-from typing import Iterable, Type
+from typing import TYPE_CHECKING
 
-from findpython.providers.base import BaseProvider, T
+from findpython.providers.base import BaseProvider
 from findpython.python import PythonVersion
 
+if TYPE_CHECKING:
+    import sys
+    from typing import Iterable
+
+    if sys.version_info >= (3, 11):
+        from typing import Self
+    else:
+        from typing_extensions import Self
+
 
 @dataclass
 class PathProvider(BaseProvider):
@@ -16,7 +25,7 @@ class PathProvider(BaseProvider):
     paths: list[Path]
 
     @classmethod
-    def create(cls: Type[T]) -> T | None:
+    def create(cls) -> Self | None:
         paths = [Path(path) for path in os.getenv("PATH", "").split(os.pathsep) if path]
         return cls(paths)
 
