@@ -1,8 +1,8 @@
 from __future__ import annotations
 
 import platform
-import typing as t
 from pathlib import Path
+from typing import TYPE_CHECKING
 
 from packaging.version import Version
 
@@ -10,6 +10,15 @@ from findpython.providers.base import BaseProvider
 from findpython.python import PythonVersion
 from findpython.utils import WINDOWS
 
+if TYPE_CHECKING:
+    import sys
+    from typing import Iterable
+
+    if sys.version_info >= (3, 11):
+        from typing import Self
+    else:
+        from typing_extensions import Self
+
 SYS_ARCHITECTURE = platform.architecture()[0]
 
 
@@ -17,12 +26,12 @@ class WinregProvider(BaseProvider):
     """A provider that finds Python from the winreg."""
 
     @classmethod
-    def create(cls) -> t.Self | None:
+    def create(cls) -> Self | None:
         if not WINDOWS:
             return None
         return cls()
 
-    def find_pythons(self) -> t.Iterable[PythonVersion]:
+    def find_pythons(self) -> Iterable[PythonVersion]:
         from findpython.pep514tools import findall as pep514_findall
 
         env_versions = pep514_findall()
@@ -36,9 +45,15 @@ class WinregProvider(BaseProvider):
                 continue
             if path.exists():
                 py_version = getattr(version.info, "version", None)
+                parse_version: Version | None = None
+                if py_version:
+                    try:
+                        parse_version = Version(py_version)
+                    except ValueError:
+                        pass
                 py_ver = self.version_maker(
                     path,
-                    Version(py_version) if py_version else None,
+                    parse_version,
                     getattr(version.info, "sys_architecture", SYS_ARCHITECTURE),
                     path,
                 )
